#"A Nonparametric Statistical Approach to Content Analysis of Items"
#Stats

#Diego Marcondes and Nilton Rogerio Marcondes
#Instituto de Matemática e Estatística, Universidade de São Paulo, Brasil
#Tel.: +55 11 97585-6644
#dmarcondes@ime.usp.br

####Application: Perception about the Evaluation of the Teaching-Learning###

source("Cochran.test.R")
library(data.table)
library(xtable)
library(rje)

#READING THE DATA
judge <- fread("Aplication.csv",colClasses = rep("factor",31))
summary(judge)

#NUMBERING THE ITEMS
colnames(judge) <- as.character(c("Specialist",1:30))

#EXPORTING THE TABLE TO LATEX
xtable(t(judge))

#COCHRAN TEST
judge <- t(judge[-c(10,11),-1]) #TEST TABLE
Q <- cochranQ(judge,0.5) #PERFORMING THE TEST
Q$Q #Q STATISTICS
Q$pvalue #P-VALUE

#CREATING TABLE OF THE PAPER
t <- cbind(Q$t,rowSums(Q$t))
t <- rbind(t,colSums(t))
xtable(t,digits = 0)

#SUBGROUPS
ps <- powerSet(1:9) #ALL SUBGROUPS

#GET ONLY THE SUBGROUPS WITH SIZE GREAT OR EQUAL TO 6
ps2 <- list()
k <- 1
for(i in 1:length(ps))
  if(length(ps[[i]]) >= 6){
    ps2[[k]] <- ps[[i]]
    k <- k + 1
  }

#PERFORMING THE TEST FOR EACH COMBINATION
Q <- vector()
pvalue <- vector()
for(i in 1:length(ps2)){
  teste <- cochranQ(m = judge[,ps2[[i]]],0.5)
  Q[i] <- teste$Q
  pvalue[i] <- teste$pvalue
}  

#RETURNING THE TABLE OF THE PAPER
group <- unlist(lapply(ps2,function(x) paste(x,collapse='')))
t2 <- data.frame(group,Q,pvalue)
t2 <- t2[order(t2$pvalue,decreasing = TRUE),]
xtable(t2[1:10,],digits = 3)

#NUMBER OF TIMES H0 WAS REJECTED
sum(pvalue < 0.05)
